@@ -51,6 +51,14 @@ enum {
     KA_PROP_TGT_RENEWABLE,
 };
 
+
+const gchar *ka_signal_names[KA_SIGNAL_COUNT] = {
+    "krb-tgt-acquired",
+    "krb-tgt-renewed",
+    "krb-tgt-expired",
+};
+
+
 struct _KaApplet {
     GObject parent;
 
@@ -73,7 +81,7 @@ struct _KaAppletPrivate {
     gboolean ns_persistence;    /* does the notification server support persistence */
 
     KaPwDialog *pwdialog;       /* the password dialog */
-    int pw_prompt_secs;         /* when to start prompting for a password */
+    int pw_prompt_secs;         /* when to start sending notifications */
     KaPluginLoader *loader;     /* Plugin loader */
 
     NotifyNotification *notification;   /* notification messages */
@@ -252,12 +260,6 @@ ka_applet_class_init (KaAppletClass *klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GParamSpec *pspec;
-
-    const gchar *signalNames[KA_SIGNAL_COUNT] = {
-        "krb-tgt-acquired",
-        "krb-tgt-renewed",
-        "krb-tgt-expired"
-    };
     int i;
 
     object_class->dispose = ka_applet_dispose;
@@ -320,7 +322,7 @@ ka_applet_class_init (KaAppletClass *klass)
     for (i = 0; i < KA_SIGNAL_COUNT; i++) {
         guint signalId;
 
-        signalId = g_signal_new (signalNames[i], G_OBJECT_CLASS_TYPE (klass),
+        signalId = g_signal_new (ka_signal_names[i], G_OBJECT_CLASS_TYPE (klass),
                                  G_SIGNAL_RUN_LAST, 0, NULL, NULL,
                                  ka_closure_VOID__STRING_UINT,
                                  G_TYPE_NONE, 2,   /* number of parameters */
@@ -528,7 +530,7 @@ ka_send_event_notification (KaApplet *self,
     }
 
     notify_notification_clear_actions(notification);
-    /* Add List Tickets button until we moved this into cc-panl */
+
     if (self->priv->ns_persistence) {
         notify_notification_add_action (notification,
                                         "ka-list-tickets",
@@ -589,14 +591,14 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     int remaining = expiry - now;
     static int last_warn = 0;
     static gboolean expiry_notified = FALSE;
+    static gboolean initial_notification = TRUE;
     static krb5_timestamp old_expiry = 0;
     gboolean notify = TRUE;
     const char *status_icon = ka_applet_select_icon (applet, remaining);
     char *tooltip_text = ka_applet_tooltip_text (remaining);
 
-
     if (remaining > 0) {
-        if (expiry_notified) {
+        if (expiry_notified || initial_notification) {
             const char* msg;
             ka_gconf_get_bool (applet->priv->gconf,
                                KA_GCONF_KEY_NOTIFY_VALID, &notify);
@@ -605,8 +607,12 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
 
                 if (applet->priv->krb_msg)
                     msg = applet->priv->krb_msg;
-                else
-                    msg = _("You've refreshed your Kerberos credentials.");
+                else {
+                    if (initial_notification)
+                        msg = _("You have valid Kerberos credentials.");
+                    else
+                        msg = _("You've refreshed your Kerberos credentials.");
+                }
                 ka_send_event_notification (applet,
                                             _("Network credentials valid"),
                                             msg,
@@ -659,6 +665,7 @@ ka_applet_update_status (KaApplet *applet, krb5_timestamp expiry)
     old_expiry = expiry;
     ka_update_tray_icon(applet, status_icon, tooltip_text);
     g_free (tooltip_text);
+    initial_notification = FALSE;
     return 0;
 }
 
@@ -707,8 +714,7 @@ ka_applet_cb_quit (GtkMenuItem *menuitem G_GNUC_UNUSED, gpointer user_data)
 {
     KaApplet *applet = KA_APPLET (user_data);
 
-    g_object_unref (applet);
-    gtk_main_quit ();
+    ka_applet_destroy (applet);
 }
 
 
@@ -730,7 +736,7 @@ ka_applet_cb_about_dialog (GtkMenuItem *menuitem G_GNUC_UNUSED,
                            "logo-icon-name", "krb-valid-ticket",
                            "copyright",
                            "Copyright (C) 2004,2005,2006 Red Hat, Inc.,\n"
-                           "2008,2009 Guido Günther",
+                           "2008-2011 Guido Günther",
                            "website-label", PACKAGE " website",
                            "website",
                            "https://honk.sigxcpu.org/piki/projects/krb5-auth-dialog/",
@@ -950,21 +956,40 @@ ka_ns_check_persistence (KaApplet *self)
 {
     GList   *caps;
     GList   *l;
+    gboolean is_autostart = g_getenv("DESKTOP_AUTOSTART_ID") ? TRUE : FALSE;
+    gint    seconds = 5;
 
     self->priv->ns_persistence = FALSE;
-    caps = notify_get_server_caps ();
-    if (caps == NULL) {
+    do {
+        caps = notify_get_server_caps ();
+        if (caps == NULL)
             g_warning ("Failed to read server caps");
-            return;
-    }
+        else {
+            l = g_list_find_custom (caps, "persistence", (GCompareFunc)strcmp);
+            if (l != NULL) {
+                self->priv->ns_persistence = TRUE;
+                KA_DEBUG ("Notification server supports persistence.");
+            }
+            g_list_foreach (caps, (GFunc) g_free, NULL);
+            g_list_free (caps);
+        }
+        /* During session start we have to wait until the shell is fully up
+         * to reliably detect the persistence property (#642666) */
+        if (is_autostart && !self->priv->ns_persistence) {
+            sleep(1);
+            seconds--;
+        } else
+            break;
+    } while (seconds);
+}
 
-    l = g_list_find_custom (caps, "persistence", (GCompareFunc)strcmp);
-    if (l != NULL) {
-        self->priv->ns_persistence = TRUE;
-        KA_DEBUG ("Notification server supports persistence.");
-    }
-    g_list_foreach (caps, (GFunc) g_free, NULL);
-    g_list_free (caps);
+
+/* destroy the applet and quit */
+void
+ka_applet_destroy (KaApplet* applet)
+{
+    g_object_unref (applet);
+    gtk_main_quit ();
 }
 
 
@@ -989,7 +1014,7 @@ ka_applet_create ()
     applet->priv->uixml = gtk_builder_new ();
     ret = gtk_builder_add_from_file (applet->priv->uixml,
                                      KA_DATA_DIR G_DIR_SEPARATOR_S
-                                     PACKAGE ".xml", &error);
+                                     PACKAGE ".ui", &error);
     if (!ret) {
         g_assert (error);
         g_assert (error->message);
